<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-lb',
'0_langue' => 'L&euml;tzebuergesch [lb]',
'0_liste' => 'spip-lb@rezo.net',
'0_mainteneur' => 'jim.wanderscheid bei gmail Punkt com',

// A
'access_interface_graphique' => 'Zer&euml;ck bei de kompletten graph&euml;schen Interface',
'access_mode_texte' => 'Vereinfachten Text-Interface weisen',
'admin_debug' => 'debug',
'admin_modifier_article' => 'D&euml;sen Artikel &auml;nneren',
'admin_modifier_auteur' => 'D&euml;sen Auteur &auml;nneren',
'admin_modifier_breve' => 'D&euml;s Kuerzmeldung &auml;nneren',
'admin_modifier_mot' => 'D&euml;st Schl&euml;sselwuert &auml;nneren',
'admin_modifier_rubrique' => 'D&euml;s Rubrik &auml;nneren',
'admin_recalculer' => 'D&euml;s S&auml;it nei berechnen',
'afficher_trad' => 'Iwersetzunge weisen',
'alerte_maj_impossible' => '<b>Alarm!</b> Den Update vun der SQL-Datekank op d\'Versioun @version@ ass onm&eacute;iglech, vill&auml;icht w&eacute;int engem Problem mat den &Auml;nnerungs-Rechter vun der Datebank. Kontakt&eacute;iert weg &auml;ren Provider.',
'alerte_modif_info_concourante' => 'OPGEPASST: D&euml;s Informatioun ass ge&auml;nnert ginn. D&eacute;i aktuell Valeur ass:',
'analyse_xml' => 'XML-Analyse',
'annuler' => 'Ofbriechen',
'antispam_champ_vide' => 'Loosst d&euml;st Feld eidel:',
'articles_recents' => 'D&eacute;i rezent Artikelen',
'avis_archive_incorrect' => 'de Backup-Fichier ass kee SPIP-Fichier',
'avis_archive_invalide' => 'de Backup-Fichier ass ong&uuml;lteg',
'avis_attention' => 'OPGEPASST!',
'avis_champ_incorrect_type_objet' => 'Falschen Feldnumm @name@ fir en Objekt vum Typ @type@',
'avis_colonne_inexistante' => 'D\'Kolonn @col@ exist&eacute;iert n&euml;t',
'avis_echec_syndication_01' => 'D\'Syndicatioun huet n&euml;t fonktionn&eacute;iert: de Backend ass n&euml;t ze dekod&eacute;ieren oder en propos&eacute;iert guer keen Artikel.',
'avis_echec_syndication_02' => 'D\'Syndicatioun huet n&euml;t fonktionn&eacute;iert: onm&eacute;iglech de Backend vun d&euml;sem Site ze ereechen.',
'avis_erreur' => 'Fehler: kuckt hei driwwer',
'avis_erreur_connexion' => 'Verbindungs-Fehler',
'avis_erreur_cookie' => 'Problem mat dem Cookie',
'avis_erreur_fonction_contexte' => 'Programm-Fehler. D&euml;s Fonktioun d&auml;rf n&euml;t an d&euml;sem Kontext opgeruff ginn.',
'avis_erreur_mysql' => 'SQL-Fehler',
'avis_erreur_sauvegarde' => 'Fehler am Backup (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Zougangs-Problem zum privaten Deel',

// B
'barre_a_accent_grave' => 'E groussen A accent grave af&uuml;gen',
'barre_aide' => 'Benotzt d&euml;s typografesch Ofkiirzungen fir &auml;re Layout ze verbesseren',
'barre_e_accent_aigu' => 'E groussen E accent aigu af&uuml;gen',
'barre_eo' => 'E verbonnenen oe af&uuml;gen',
'barre_eo_maj' => 'E groussen verbonnenen OE af&uuml;gen',
'barre_euro' => 'En &euro;-Symbol af&uuml;gen',
'barre_gras' => '{{Fett}} maachen',
'barre_guillemets' => 'T&euml;schent franz&eacute;isch Anf&uuml;hrungszeechen s&auml;tzen',
'barre_guillemets_simples' => 'T&euml;schent d&auml;itsch Anf&uuml;hrungszeechen s&auml;tzen',
'barre_intertitre' => 'An eng {{{Iwwerschr&euml;ft}}} &auml;nneren',
'barre_italic' => '{Kursiv} maachen',
'barre_lien' => 'An e [Link->http://...] &auml;nneren',
'barre_lien_input' => 'Gidd d\'Adress vum Link un (dir k&euml;nnt eng Internet-Adress &euml;nner der Form http://www.site.lu/asw oder einfach d\'Nummer vun engem Artikel vun d&euml;sem Site uginn.',
'barre_note' => 'An eng [[Foussnote]] &auml;nneren',
'barre_paragraphe' => 'Paragraph derb&auml;i setzen',
'barre_quote' => '<quote>Citatioun</quote> vun engem Text',
'bouton_ajouter_document' => 'Dokument derb&auml;i setzen',
'bouton_ajouter_image' => 'Bild derb&auml;i setzen',
'bouton_ajouter_image_document' => 'E Bild oder en Dokument derb&auml;i setzen',
'bouton_changer' => '&Auml;nneren',
'bouton_chercher' => 'Sichen',
'bouton_choisir' => 'Auswielen',
'bouton_download' => 'Eroflueden',
'bouton_enregistrer' => 'Sp&auml;icheren',
'bouton_radio_desactiver_messagerie_interne' => 'D&eacute;i intern Messagerie ausschalten',
'bouton_radio_envoi_annonces' => 'Editorial Annoncen sch&eacute;cken',
'bouton_radio_non_envoi_annonces' => 'Keng Neiegkeeten sch&eacute;cken',
'bouton_radio_non_envoi_liste_nouveautes' => 'Keng L&euml;scht vun de Neiegkeeten sch&eacute;cken',
'bouton_recharger_page' => 'd&euml;s S&auml;it nei lueden',
'bouton_telecharger' => 'Eroplueden',
'bouton_valider' => 'Valid&eacute;ieren',

// C
'cal_apresmidi' => 'Nom&euml;tteg',
'cal_jour_entier' => 'Ganzen Dag',
'cal_matin' => 'Muerges',
'cal_par_jour' => 'Kalenner vum Dag',
'cal_par_mois' => 'Kalenner vum Mount',
'cal_par_semaine' => 'Kalenner vun der Woch',
'choix_couleur_interface' => 'Farw',
'choix_interface' => 'Wiel vum Interface',
'colonne' => 'Kolonn',
'confirm_changer_statut' => 'Opgepasst, dir w&euml;llt de Status vun d&euml;sem Element &auml;nneren. W&euml;llt dir weiderfueren?',
'correcte' => 'richteg',

// D
'date_aujourdhui' => 'haut',
'date_avant_jc' => 'virun J.C.',
'date_dans' => 'an @delai@',
'date_de_mois_1' => '@j@. @nommois@',
'date_de_mois_10' => '@j@. @nommois@',
'date_de_mois_11' => '@j@. @nommois@',
'date_de_mois_12' => '@j@. @nommois@',
'date_de_mois_2' => '@j@. @nommois@',
'date_de_mois_3' => '@j@. @nommois@',
'date_de_mois_4' => '@j@. @nommois@',
'date_de_mois_5' => '@j@. @nommois@',
'date_de_mois_6' => '@j@. @nommois@',
'date_de_mois_7' => '@j@. @nommois@',
'date_de_mois_8' => '@j@. @nommois@',
'date_de_mois_9' => '@j@. @nommois@',
'date_demain' => 'muer',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ um @heure@',
'date_fmt_jour_mois' => '@jour@. @nommois@',
'date_fmt_jour_mois_annee' => '@jour@. @nommois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => '@nomjour@, den @date@',
'date_heures' => 'Stonnen',
'date_hier' => 'g&euml;schter',
'date_il_y_a' => 'virun @delai@',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Sonndeg',
'date_jour_1_abbr' => 'Son.',
'date_jour_1_initiale' => 'S.',
'date_jour_2' => 'M&eacute;indeg',
'date_jour_2_abbr' => 'M&eacute;i.',
'date_jour_2_initiale' => 'M.',
'date_jour_3' => 'D&euml;nschdeg',
'date_jour_3_abbr' => 'D&euml;n.',
'date_jour_3_initiale' => 'D.',
'date_jour_4' => 'M&euml;ttwoch',
'date_jour_4_abbr' => 'M&euml;t.',
'date_jour_4_initiale' => 'M.',
'date_jour_5' => 'Donneschdeg',
'date_jour_5_abbr' => 'Don.',
'date_jour_5_initiale' => 'D.',
'date_jour_6' => 'Freideg',
'date_jour_6_abbr' => 'Fre.',
'date_jour_6_initiale' => 'F.',
'date_jour_7' => 'Samschdeg',
'date_jour_7_abbr' => 'Sam.',
'date_jour_7_initiale' => 'S.',
'date_jours' => 'Deg',
'date_minutes' => 'Minuten',
'date_mois' => 'M&eacute;int',
'date_mois_1' => 'Januar',
'date_mois_10' => 'Oktober',
'date_mois_11' => 'November',
'date_mois_12' => 'Dezember',
'date_mois_2' => 'Februar',
'date_mois_3' => 'M&auml;rz',
'date_mois_4' => 'Abr&euml;l',
'date_mois_5' => 'Mee',
'date_mois_6' => 'Juni',
'date_mois_7' => 'Juli',
'date_mois_8' => 'August',
'date_mois_9' => 'September',
'date_saison_1' => 'Wanter',
'date_saison_2' => 'Fr&eacute;ijor',
'date_saison_3' => 'Summer',
'date_saison_4' => 'Hierscht',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'Wochen',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => ' fir d\'Installatioun richteg unzef&auml;nken',
'dirs_preliminaire' => 'Fir d\'&eacute;ischt: <b>R&eacute;gl&eacute;iert d\'Zougangs-Rechter</b>',
'dirs_probleme_droits' => 'Problem mat den Zougangs-Rechter',
'dirs_repertoires_absents' => '<p><b>D&euml;s Dossier\'en konnten n&euml;t fonnt ginn:</b></p><ul>@bad_dirs@.</ul>
<p>Warscheinl&euml;ch ass dat e Problem vu Grouss- oder Kleng-Schreiwen.
Kontroll&eacute;iert op d&eacute;i grouss an d&eacute;i kleng Buchstawen mat deem wat hei ugewisen g&euml;t iwwerteneenst&euml;mmen;
wann dat n&euml;t de Fall ass, &auml;nnert de Numm vun den Dossier\'en mat &auml;rer FTP-Software fir de Fehler ze verbesseren.
<p>Wann dat gemaach ass, da k&euml;nnt dier',
'dirs_repertoires_suivants' => '<p><b>D&euml;s Dossier\'en k&euml;nnen n&euml;t beschriwwen ginn:</b></p><ul>@bad_dirs@.</ul>
<p>Fir dat ze verbesseren, benotzt &auml;ren FTP-Client fir d\'Zougangsrechter vun jidfer Dossier anzestellen.
D&euml;s Prozedur ass am Detail am Installatiouns-Guide beschriwwen.<p>
<p>Wann dat gemaach ass, da k&euml;nnt dier ',
'double_occurrence' => 'K&euml;nnt duebel fir', # MODIF

// E
'en_cours' => 'am gaangen',
'entree_dimensions' => 'Gr&eacute;issten:',
'entree_titre_document' => 'Titel vum Dokument:',
'entree_titre_image' => 'Titel vum Bild:',
'envoi_via_le_site' => 'Via &auml;ren Site sch&eacute;cken',
'erreur' => 'Fehler',
'erreur_balise_non_fermee' => 'L&auml;schten Tag deen n&euml;t zou ass:',
'erreur_texte' => 'Fehler(en)',
'etape' => 'Etape',

// F
'fichier_introuvable' => 'De Fichier @fichier@ kann n&euml;t font ginn',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Dir sidd schon ugemelt.',
'form_email_non_valide' => '&Auml;r Email-Adress ass n&euml;t richteg.',
'form_forum_access_refuse' => 'Dir hutt keen Zougang m&eacute;i zu d&euml;sem Site.',
'form_forum_bonjour' => 'Moien @nom@,',
'form_forum_email_deja_enregistre' => 'D&euml;s Email-Adress ass schon ageschriwen, dir k&euml;nnt also &auml;rt normadt Passwuert benotzen.',
'form_forum_identifiant_mail' => '&Auml;re neie Login gouf Iech lo grad per Email gesch&eacute;ckt.',
'form_forum_identifiants' => 'Pers&eacute;inlech Identifikatiounen',
'form_forum_indiquer_nom_email' => 'Gidd hei &auml;re Numm an &auml;ren Email un. &Auml;re pers&eacute;inlechen Login kritt d&euml;r per Email gesch&eacute;ckt.',
'form_forum_login' => 'Login:',
'form_forum_message_auto' => '(d&euml;st ass eng automat&euml;sch &Auml;ntwert)',
'form_forum_pass' => 'Passwuert:',
'form_forum_probleme_mail' => 'Problem mam Email: de Login ka n&euml;t gesch&eacute;ckt ginn.',
'form_forum_voici1' => 'Hei sinn &auml;r Identifikatiounen fir beim Liewen vum Site "@nom_site_spip@" (@adresse_site@) matzemaachen:',
'form_forum_voici2' => 'Hei sinn &auml;re Identifikatiounen fir Artikelen um Site "@nom_site_spip@" (@adresse_login@) ze propos&eacute;ieren:',
'form_indiquer_email' => 'Gidd weg &auml;r Email-Adress un.',
'form_indiquer_nom' => 'Gidd weg &auml;re Numm un.',
'form_indiquer_nom_site' => 'Gidd weg de Numm vun &auml;rem Site un.',
'form_pet_adresse_site' => 'Adress vun &auml;rem Site',
'form_pet_aucune_signature' => '&Euml;t entspr&euml;cht keng &Euml;nnerschr&euml;ft d&euml;sem Kode...',
'form_pet_confirmation' => 'Konfirm&eacute;iert weg &auml;r &Euml;nnerschr&euml;ft:',
'form_pet_deja_enregistre' => 'D&euml;se Site ass schon ageschriwen',
'form_pet_deja_signe' => 'Dir hutt d&euml;sen Text schon &euml;nnerschriwen.',
'form_pet_envoi_mail_confirmation' => 'E Konfirmatiouns-Email gouf lo grad un @email@ gesch&eacute;ckt. Dir musst op d&eacute;i Adress surfen d&eacute;i am Email steet fir &auml;r &Euml;nnerschr&euml;ft ze best&auml;tegen.',
'form_pet_mail_confirmation' => 'Bonjour,

Dir hutt gefroot fir d\'Petitioun:
@titre@
ze &euml;nnerschreiwen.

Dir hutt d&eacute;i hei Informatiounen uginn:
    Numm: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

WICHTEG...
Fir &auml;r &Euml;nnerschr&euml;ft ze valid&eacute;ieren, surft op d&euml;s Adress (am aneren Fall g&euml;t &auml;r Demande verworf):

    @url@


Merci fir &auml;r Participatioun
',
'form_pet_message_commentaire' => 'E Message, e Kommentar?',
'form_pet_nom_site2' => 'Numm vun &auml;rem Site',
'form_pet_probleme_liens' => 'Korrig&eacute;iert &auml;re Message a maacht d\'Hypertext-Linken ewech.',
'form_pet_probleme_technique' => 'Techn&euml;sche Problem, d\'&Euml;nnerschr&euml;ften si momentan ausser Betrieb.',
'form_pet_signature_pasprise' => '&Auml;r &Euml;nnerschr&euml;ft ass n&euml;t ugeholl ginn.',
'form_pet_signature_validee' => '&Auml;r &Euml;nnerschr&euml;ft ass valid&eacute;iert. Merci!',
'form_pet_site_deja_enregistre' => 'D&euml;se Site ass schon ageschriwen',
'form_pet_url_invalide' => 'D\'URL d&eacute;i der uginn hutt ass n&euml;t richteg.',
'form_pet_votre_email' => '&Auml;r Email-Adress',
'form_pet_votre_nom' => '&Auml;re Numm oder Pseudo',
'form_pet_votre_site' => 'Wann dir e Web-Site hutt, da k&euml;nnt d&euml;r en hei uginn',
'form_prop_confirmer_envoi' => 'Konfirm&eacute;iert d\'Sch&eacute;cken',
'form_prop_description' => 'Beschreiwung/Kommentar',
'form_prop_enregistre' => '&Auml;r Propositioun ass enregistr&eacute;iert, si geet online wann se vun engem Responsabelen vun desem Site valid&eacute;iert ass.',
'form_prop_envoyer' => 'E Message sch&eacute;cken',
'form_prop_indiquer_email' => 'Gidd weg eng richteg Email-Adress un',
'form_prop_indiquer_nom_site' => 'Gidd weg de Numm vum Site un.',
'form_prop_indiquer_sujet' => 'Gidd weg e Sujet un',
'form_prop_message_envoye' => 'Message gesch&eacute;ckt',
'form_prop_nom_site' => 'Numm vum Site',
'form_prop_non_enregistre' => '&Auml;r Propose ass n&euml;t enregistr&eacute;iert ginn.',
'form_prop_sujet' => 'Sujet',
'form_prop_url_site' => 'Adress (URL) vum Site',
'forum_acces_refuse' => 'Dir hutt keen Zougang m&eacute;i zu d&euml;se Forum\'en.',
'forum_attention_dix_caracteres' => '<b>Opgepasst!</b> &Auml;re Message muss op manst 10 Buchstawen hun.',
'forum_attention_trois_caracteres' => '<b>Opgepasst!</b> &Auml;ren Titel muss op manst 3 Buchstawen hun.',
'forum_attention_trop_caracteres' => '<b>Opgepasst!</b> &Auml;re Message ass ze laang (@compte@ Buchstawen): fir enregistr&eacute;iert ze ginn d&auml;rf hien n&euml;t m&eacute;i w&eacute;i @max@ Buchstawen hun.',
'forum_avez_selectionne' => 'Dir hutt gewielt:',
'forum_cliquer_retour' => '<a href=\'@retour_forum@\'>Hei klicken</a> fir weider.',
'forum_forum' => 'Forum',
'forum_info_modere' => 'D&euml;se Forum ass &agrave; priori moder&eacute;iert: &auml;re Beitrag geet er&eacute;ischt online wann e vun engem Administrateur vum Site valid&eacute;iert ass.',
'forum_lien_hyper' => '<b>Link</b> (optionnel)',
'forum_message_definitif' => 'Definitive Message: op de Site sch&eacute;cken',
'forum_message_trop_long' => '&Auml;re Message ass ze laang. D\'maximal Gr&eacute;isst sin 20.000 Buchstawen.',
'forum_ne_repondez_pas' => '&Auml;ntwert n&euml;t op d&euml;sen Email, mais um Forum op d&euml;ser Adress:',
'forum_non_inscrit' => 'Dir sidd n&euml;t ugemellt, oder d\'Adress oder d\'Passwuert si falsch.',
'forum_page_url' => '(Wann &auml;re Message sech op en Artikel vum Internet bezitt oder op eng S&auml;it d&eacute;i m&eacute;i Informatiounen g&euml;t, k&euml;nnt dir hei den Titel an d\'Adress vun der S&auml;it uginn.)',
'forum_par_auteur' => 'No @auteur@',
'forum_poste_par' => 'Message gesch&eacute;ckt vun @parauteur@ als Suite vum Artikel "@titre@".',
'forum_probleme_database' => 'Problem mat der Datebank, &auml;re Message gouf n&euml;t enregistr&eacute;iert.',
'forum_qui_etes_vous' => '<b>Wie sidd Dir?</b> (optionnel)',
'forum_texte' => 'Text vun &auml;rem Message:',
'forum_titre' => 'Titel:',
'forum_titre_erreur' => 'Fehler...',
'forum_url' => 'URL:',
'forum_valider' => '&Auml;r Wiel valid&eacute;ieren',
'forum_voir_avant' => 'D&euml;se Message kucken ier e gesch&eacute;ckt g&euml;t',
'forum_votre_email' => '&Auml;r Email-Adress:',
'forum_votre_nom' => '&Auml;re Numm (oder Pseudo):',
'forum_vous_enregistrer' => 'Fir bei d&euml;sem Forum matzemaachen, muss dir Iech fir d\'&eacute;ischt umelden. Gidd hei &auml;r pers&eacute;inlech Identifikatioun un d&eacute;i der krut. Wann dir n&euml;t ugemelt sidd, da musst dir',
'forum_vous_inscrire' => 'Iech aschreiwen.',

// I
'ical_texte_rss_articles' => 'De "Backend"-Fichier vun den Artikelen vun d&euml;sem Site ass op d&euml;r Adress:',
'ical_texte_rss_articles2' => 'Dir k&euml;nnt och "Backend"-Fichier\'en fir d\'Artikelen vun all Rubrik vum Site kr&eacute;ien:',
'ical_texte_rss_breves' => 'Et g&euml;t en plus e Fichier mat de Kuerzmeldungen vum Site. Wann dir d\'Nummer vun enger Rubrik ugitt, da kritt der just d\'Kuerzmeldungen vun d&auml;r Rubrik.',
'icone_a_suivre' => 'Aufgaben',
'icone_admin_site' => 'Administratioun vum Site',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'H&euml;llef',
'icone_articles' => 'Artikelen',
'icone_auteurs' => 'Auteuren',
'icone_breves' => 'Kuerzmeldungen',
'icone_brouteur' => 'Schnell-Navigatioun',
'icone_configuration_site' => 'Konfiguratioun',
'icone_configurer_site' => '&Auml;re Site konfigur&eacute;ieren',
'icone_creer_nouvel_auteur' => 'Neien Auteur derb&auml;i setzen',
'icone_creer_rubrique' => 'Rubrik derb&auml;i setzen',
'icone_creer_sous_rubrique' => '&Euml;nner-Rubrik derb&auml;i setzen',
'icone_deconnecter' => 'S&euml;ch ofmelden',
'icone_discussions' => 'Diskussiounen',
'icone_doc_rubrique' => 'Dokumenter',
'icone_ecrire_article' => 'Neien Artikel schreiwen',
'icone_edition_site' => 'Editioun',
'icone_forum_administrateur' => 'Forum vun den Adminstrateuren',
'icone_forum_suivi' => 'Suivi vun den Forum\'en',
'icone_gestion_langues' => 'Gestioun vun de Sproochen',
'icone_informations_personnelles' => 'Pers&eacute;inl&euml;ch Informatiounen',
'icone_interface_complet' => 'Kompletten Interface',
'icone_interface_simple' => 'Einfachen Interface',
'icone_maintenance_site' => 'Maintenance vum Site',
'icone_messagerie_personnelle' => 'Pers&eacute;inlech Messagerie',
'icone_mots_cles' => 'Schl&euml;sselwierder',
'icone_nouvelle_breve' => 'Nei Kuerzmeldung schreiwen',
'icone_repartition_actuelle' => 'D&eacute;i aktuell Verdeelung weisen',
'icone_repartition_debut' => 'D\'Verdeelung s&auml;it dem Ufank weisen',
'icone_repartition_visites' => 'Verdeelung vun de Visiten',
'icone_rubriques' => 'Rubriken',
'icone_sauver_site' => 'Site s&euml;cheren',
'icone_site_entier' => 'De ganzen Site',
'icone_sites_references' => 'Referenz&eacute;iert Siten',
'icone_statistiques' => 'Statistik vum Site',
'icone_statistiques_visites' => 'Statistik',
'icone_suivi_activite' => 'D\'Liewen vum Site verfolgen',
'icone_suivi_actualite' => 'Evolutioun vum Site',
'icone_suivi_forums' => 'Forum\'en verfolgen',
'icone_suivi_pettions' => 'Petitiounen verfolgen',
'icone_suivi_revisions' => '&Auml;nnerungen vun den Artikelen',
'icone_supprimer_document' => 'D&euml;st Dokument l&auml;schen',
'icone_supprimer_image' => 'D&euml;st Bild l&auml;schen',
'icone_supprimer_message' => 'D&euml;se Message l&auml;schen',
'icone_tous_articles' => 'All &auml;r Artikelen',
'icone_tous_auteur' => 'All d\'Auteuren',
'icone_valider_message' => 'D&euml;se Message valid&eacute;ieren',
'icone_visiter_site' => 'Ukucken',
'icone_voir_en_ligne' => 'Online weisen',
'image_tourner_180' => '180&deg; dr&eacute;ien',
'image_tourner_droite' => '90&deg; no riets dr&eacute;ien',
'image_tourner_gauche' => '90&deg; no l&eacute;nks dr&eacute;ien',
'img_indisponible' => 'Bild fehlt',
'impossible' => 'onm&eacute;iglech',
'info_a_suivre' => 'AUFGABEN"',
'info_a_valider' => '[ze valid&eacute;ieren]',
'info_acces_interdit' => 'Zougang gespaart',
'info_acces_refuse' => 'Zougang gespaart',
'info_action' => 'Aktioun: @action@',
'info_administrer_rubriques' => 'Dir k&euml;nnt d&euml;s Rubrik an hier &Euml;nner-Rubriken administr&eacute;ieren',
'info_adresse_non_indiquee' => 'Dir hutt keng Test-Adress uginn!',
'info_aide' => 'H&Euml;LLEF:',
'info_ajouter_mot' => 'D&euml;st Wuert derb&auml;i setzen',
'info_annonce' => 'ANNONCE',
'info_annonces_generales' => 'Generell Annoncen:',
'info_article_propose' => 'Propos&eacute;ierten Artikel',
'info_article_publie' => 'Publiz&eacute;ierten Artikel',
'info_article_redaction' => 'Artikel an der Aarbecht',
'info_article_refuse' => 'Refus&eacute;ierten Artikel',
'info_article_supprime' => 'Gel&auml;schten Artikel',
'info_articles' => 'Artikelen',
'info_articles_a_valider' => 'Artikelen fir ze valid&eacute;ieren',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Propos&eacute;iert Artikelen',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'Auteur(en):',
'info_authentification_ftp' => 'Umeldung (per FTP).',
'info_bloquer_lien' => 'Link block&eacute;ieren',
'info_breves_02' => 'Kuerzmeldungen',
'info_breves_2' => 'Kuerzmeldungen',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Kuerzmeldungen fir ze valid&eacute;ieren',
'info_connexion_refusee' => 'D\'Verbindung gouf refus&eacute;iert.',
'info_contact_developpeur' => 'Kontakt&eacute;iert w.e.g. en D&eacute;veloppeur.',
'info_contenance' => 'D&euml;se Site huet:',
'info_contribution' => 'Beitr&auml;g an de Forum\'en',
'info_copyright' => '@spip@ ass eng fr&auml;i Software d&eacute;i &euml;nner @lien_gpl@ verdeelt g&euml;t.',
'info_copyright_doc' => 'Fir m&eacute;i Informatiounen, kuckt op <a href="@spipnet@">http://www.spip.net/lb</a>.',
'info_copyright_gpl' => '&euml;nner GPL-Lizenz',
'info_cours_edition' => '&Auml;r Artikelen an der Aarbecht',
'info_creer_repertoire' => 'Setzt e Fichier oder Dossier mat d&euml;sem Numm derb&auml;i:',
'info_creer_repertoire_2' => 'am Dossier <b>ecrire/data</b>, dann:',
'info_creer_vignette' => 'Automat&euml;sch Vignetten maachen',
'info_deplier' => 'Opklappen',
'info_descriptif_nombre' => 'Beschreiwung(en):',
'info_description' => 'Beschreiwung:',
'info_description_2' => 'Beschreiwung:',
'info_dimension' => 'Gr&eacute;isst:',
'info_document' => 'Dokument',
'info_document_indisponible' => 'D&euml;st Dokument g&euml;tt &euml;t n&euml;t',
'info_documents' => 'Dokumenter',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP erlaabt d\'Sch&eacute;cken vu Messagen a privat Forum\'en t&euml;schent den Mataarbechter vum Site. Dir k&euml;nnt d&euml;s Fonktionnalit&eacute;it an- oder ausschalten.',
'info_ecire_message_prive' => 'E privaten Message sch&eacute;cken',
'info_email_invalide' => 'Falsch Email-Adress.',
'info_en_cours_validation' => '&Auml;r Artikelen an der Aarbecht',
'info_en_ligne' => 'Elo online:',
'info_envoyer_message_prive' => 'D&euml;sem Auteur e privaten Message sch&eacute;cken',
'info_erreur_requete' => 'Fehler am Query:',
'info_erreur_squelette2' => '&Euml;t g&euml;t kee Skelett <b>@fichier@</b> ...',
'info_erreur_systeme' => 'System-Fehler (errno @errsys@)',
'info_erreur_systeme2' => 'Den Harddisk ass vill&auml;icht voll oder d\'Datebank futti.
<span style=\'color:#f00\'>Versicht <a href=\'@script@\'>d\'Datebank ze fl&eacute;cken</a>,
oder kontakt&eacute;iert &auml;re Provider.</span>',
'info_fini' => '&Euml;t ass f&auml;rdeg!',
'info_format_image' => 'Bild-Formater d&eacute;i k&euml;nnen benotzt ginn fir Vignetten ze maachen: @gd_formats@.',
'info_format_non_defini' => 'Format n&euml;t defin&eacute;iert',
'info_grand_ecran' => 'Groussen &Eacute;cran',
'info_image_aide' => 'H&Euml;LLEF',
'info_image_process_titre' => 'Fabrikatiouns-Method fir d\'Vignetten',
'info_impossible_lire_page' => '<b>Felhler!</b> Onm&eacute;igl&euml;ch d\'S&auml;it <tt><html>@test_proxy@</html></tt> duerch de Proxy ze liesen',
'info_inclusion_directe' => 'Direkt Abannung:',
'info_inclusion_vignette' => 'Ubannen vun der Vignette:',
'info_installation_systeme_publication' => 'Installatioun vum System...',
'info_installer_documents' => 'Dir k&euml;nnt automat&euml;sch all d\'Dokumenter aus dem Dossier @upload@ install&eacute;ieren.',
'info_installer_ftp' => 'Als Administrateur k&euml;nnt dir Fichier\'en per FTP an den Dossier @upload@ eroplueden an se dann hei auswielen.',
'info_installer_images' => 'Dir k&euml;nnt Biller am Format JPEG, GIF oder PNG eroplueden.',
'info_installer_images_dossier' => 'Biller an den Dossier @upload@ eroplueden fir se hei k&euml;nnen auszewielen.',
'info_installer_tous_documents' => 'All d\'Dokumenter eroplueden',
'info_interface_complete' => 'Kompletten Interface',
'info_interface_simple' => 'Einfachen Interface',
'info_joindre_document_article' => 'Dier k&euml;nnt bei d&euml;sen Artikel Dokumenter derb&auml;i setzen vum Typ',
'info_joindre_document_rubrique' => 'Dir k&euml;nnt bei d&euml;s Rubrik Dokumenter derb&auml;i setzen vum Typ',
'info_joindre_documents_article' => 'Dir k&euml;nnt bei d&euml;sen Artikel Dokumenter derb&auml;i setzen vum Typ:',
'info_l_article' => 'den Artikel',
'info_la_breve' => 'd\'Kuerzmeldung',
'info_la_rubrique' => 'd\'Rubrik',
'info_langue_principale' => 'Haapt-Sprooch vum Site',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ Pixel',
'info_les_auteurs_1' => 'vun @les_auteurs@',
'info_logo_format_interdit' => 'N&euml;mmen d\'Logoen mam Format @formats@ ginn ugeholl.',
'info_logo_max_poids' => 'D\'Logoen mussen manner w&eacute;i @maxi@ hun (d&euml;se Fichier huet @actuel@).',
'info_logo_max_taille' => 'D\'Logoen mussen manner w&eacute;i @maxi@ hun (d&euml;se Fichier huet @actuel@).',
'info_mail_fournisseur' => 'numm@provider.lu',
'info_message_2' => 'MESSAGE',
'info_message_supprime' => 'MESSAGE GEL&Auml;SCHT',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Publikatiouns-Datum:',
'info_modification_parametres_securite' => '&Auml;nnerung vun de S&euml;cherheets-Parameteren',
'info_mois_courant' => 'An d&euml;sem Mount:',
'info_mot_cle_ajoute' => 'D\'Schl&euml;sselwuert gouf derb&auml;i gesat bei',
'info_multi_herit' => 'Haapt-Sprooch',
'info_multi_langues_soulignees' => 'D&eacute;i <u>&euml;nnerstrache Sproochen</u> hun eng komplett Iwersetzung vum Interface. Wann dier d&euml;s Sprooche wielt, da ginn vill Elementer vum &ouml;ffentl&euml;che Site (Datumen, Formulairen) automatesch iwersaat. Bei de n&euml;t &euml;nnerstrache Sproochen ersch&eacute;ngen d&euml;s Elementer an der Haaptsprooch vum Site.',
'info_multilinguisme' => 'Verschidden Sproochen',
'info_nom_non_utilisateurs_connectes' => '&Auml;re Numm ass n&euml;t op der L&euml;scht vun den ugemelden Benotzer.',
'info_nom_utilisateurs_connectes' => '&Auml;re Numm k&euml;nnt op d\'L&euml;scht vun den ugemelten Benotzer.',
'info_nombre_en_ligne' => 'Elo ugemelt:',
'info_non_resultat' => 'Keen Resultat fir "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Dir benotzt d&eacute;i intern Messagerie vun d&euml;sem Site n&euml;t.',
'info_nouveau_message' => 'DIER HUTT E NEIE MESSAGE',
'info_nouveaux_messages' => 'DIR HUTT @total_messages@ NEI MESSAGEN',
'info_numero_abbreviation' => 'Nr&nbsp;',
'info_obligatoire' => 'D&euml;s Informatioun ass obligatoresch',
'info_panne_site_syndique' => 'Pann vum syndiqu&eacute;ierten Site',
'info_pense_bete' => 'NOTIZBLOC',
'info_petit_ecran' => 'Klengen &Eacute;cran',
'info_petition_close' => 'Petitioun ofgeschloss',
'info_pixels' => 'Pixel',
'info_plusieurs_mots_trouves' => 'E puer Schl&euml;sselwierder fonnt fir "@cherche_mot@":',
'info_popularite_5' => 'Popularit&eacute;it:',
'info_portfolio' => 'Portefeuille',
'info_portfolio_automatique' => 'Automat&euml;schen Portfolio:',
'info_premier_resultat' => '[@debut_limit@ &eacute;ischt Resultater vun @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ &eacute;ischt Resultater vun @total@]',
'info_probleme_grave' => 'Problem mat',
'info_propose_1' => '[@nom_site_spip@] Propos&eacute;iert: @titre@',
'info_propose_2' => 'Propos&eacute;ierten Artikel
---------------------',
'info_propose_3' => 'Den Artikel "@titre@" g&euml;t fir d\'Publikatioun propos&eacute;iert.',
'info_propose_4' => 'Dir sitt agelueden Iech &euml;n unzekucken an &auml;ren Avis ze ginn',
'info_propose_5' => 'am Forum deen zu him geh&eacute;iert. Dir fannt &euml;n op der Adress:',
'info_publie_01' => 'Den Artikel "@titre@" ass vum @connect_nom@ valid&eacute;iert ginn.',
'info_publie_1' => '[@nom_site_spip@] PUBLIZ&Eacute;IERT: @titre@',
'info_publie_2' => 'Publiz&eacute;ierten Artikel
---------------------',
'info_rechercher' => 'Sichen',
'info_rechercher_02' => 'Sichen:',
'info_remplacer_vignette' => 'D\'Vignette duerch e speziellen Logo ers&auml;tzen:',
'info_retablir_lien' => 'D&euml;se Link zer&euml;cksetzen',
'info_retirer_mot' => 'D&euml;st Wuert l&auml;schen',
'info_retirer_mots' => 'D\'Wierder all l&auml;schen',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'ouni Titel',
'info_selectionner_fichier' => 'Dir k&euml;nnt e Fichier aus dem Dossier @upload@ wielen',
'info_selectionner_fichier_2' => 'Wielt e Fichier:',
'info_signature_supprimee' => '&Euml;nnerschr&euml;ft gel&auml;scht',
'info_signature_supprimee_erreur' => 'Fehler: d&euml;se L&auml;sch-Code entspr&euml;cht k&eacute;nger &Euml;nnerschr&euml;ft',
'info_site_attente' => 'Site waard op d\'Validatioun',
'info_site_reference' => 'Referenz&eacute;ierten Site, publiz&eacute;iert',
'info_site_refuse' => 'Refus&eacute;ierten Site',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'E Site referenz&eacute;ieren',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'Vignette l&auml;schen',
'info_symbole_bleu' => 'Dat <b>blot</b> Symbol weist eng <b>Notiz</b>: also e pers&eacute;inlechen Message.',
'info_symbole_jaune' => 'Dat <b>gielt</b> Symbol weist eng <b>Annonce un all d\'Redakteren</b>, &auml;nnerbar duerch d\'Administrateuren, a sichtbar vun allen Redakteren.',
'info_symbole_vert' => 'Dat <b>gr&eacute;ngt</b> Symbol weist <b>Messagen t&euml;schent de Benotzer</b> vum Site.',
'info_syndication' => 'Syndicatioun:',
'info_syndication_articles' => 'Artikel(en)',
'info_telecharger' => 'Vun &auml;rem Computer eroplueden:',
'info_telecharger_nouveau_logo' => 'E neie Logo eroplueden:',
'info_telecharger_ordinateur' => 'Vun &auml;rem Computer eroplueden:',
'info_tous_resultats_enregistres' => '[all d\'Resultater si gesp&auml;ichert]',
'info_tout_afficher' => 'Alles weisen',
'info_travaux_texte' => 'D&euml;se Site ass nach n&euml;t konfigur&eacute;iert. Kommt m&eacute;i sp&eacute;it er&euml;m...',
'info_travaux_titre' => 'Chantier um Site',
'info_trop_resultat' => 'Zevill Resultater fir "@cherche_mot@"; verbessert &auml;r Sich.',
'info_utilisation_messagerie_interne' => 'Dir k&euml;nnt d&eacute;i intern Messagerie vun d&euml;sem Site benotzen.',
'info_valider_lien' => 'd&euml;se Link valid&eacute;ieren',
'info_verifier_image' => ', kontroll&eacute;iert op &auml;r Biller richteg gelueden goufen.',
'info_vignette_defaut' => 'Default-Vignette',
'info_vignette_personnalisee' => 'Personnalis&eacute;iert Vignette',
'info_visite' => 'Visite:',
'info_visites' => 'Visiten:',
'info_vos_rendez_vous' => '&Auml;r Rendez-vous\'en',
'info_zoom' => 'Zoom',
'infos_vos_pense_bete' => '&Auml;r Notizen',
'item_breve_proposee' => 'Propos&eacute;iert Kuerzmeldung',

// L
'lien_afficher_icones_seuls' => 'N&euml;mmen d\'Ikonen weisen',
'lien_afficher_texte_icones' => 'D\'Ikonen an d\'Texter weisen',
'lien_afficher_texte_seul' => 'N&euml;mmen d\'Texter weisen',
'lien_liberer' => 'fr&auml;i ginn',
'lien_liberer_tous' => 'd&euml;s Artikelen fr&auml;i ginn',
'lien_nouvea_pense_bete' => 'NEI NOTIZ',
'lien_nouveau_message' => 'NEIE MESSAGE',
'lien_nouvelle_annonce' => 'NEI ANNONCE',
'lien_petitions' => 'PETITIOUN',
'lien_popularite' => 'Popularit&eacute;it: @popularite@%',
'lien_racine_site' => 'WUERZEL VUM SITE',
'lien_reessayer' => 'nach eng K&eacute;ier prob&eacute;ieren',
'lien_repondre_message' => 'Op d&euml;se Message &auml;ntweren',
'lien_supprimer' => 'l&auml;schen',
'lien_tout_afficher' => 'Alles weisen',
'lien_visite_site' => 'd&euml;se Site kucken',
'lien_visites' => '@visites@&nbsp;Visiten',
'lien_voir_auteur' => 'D&euml;sen Auteur weisen',
'ligne' => 'Ligne',
'login' => 'Verbindung',
'login_acces_prive' => 'Zougang zum privaten Deel',
'login_autre_identifiant' => 'sech &euml;nnert engem aneren Login umelden',
'login_cookie_accepte' => 'R&eacute;gl&eacute;iert &auml;re Browser dat e Cookien unh&euml;llt (op mannst fir d&euml;se Site).',
'login_cookie_oblige' => 'Fir Iech op d&euml;sem Site s&euml;cher unzemelden musst Dir d\'Cookien unhuelen.',
'login_deconnexion_ok' => 'Ofgemeld.',
'login_erreur_pass' => 'Falscht Passwuert.',
'login_espace_prive' => 'privaten Deel',
'login_identifiant_inconnu' => 'De Login &laquo; @login@ &raquo; ass n&euml;t bekannt.',
'login_login' => 'Login:',
'login_login2' => 'Login (Identifikatioun fir d&euml;se Site):',
'login_login_pass_incorrect' => '(Login oder Passwuert falsch.)',
'login_motpasseoublie' => 'Passwuert&nbsp;vergiess?',
'login_non_securise' => 'Opgepasst, d&euml;se Formulaire ass n&euml;t ges&euml;chert.
Wann dir n&euml;t w&euml;llt dat &auml;rt Passwuert ka um Internet ofgefaangen ginn, aktiv&eacute;iert Javascript an &auml;rem Browser an',
'login_nouvelle_tentative' => 'Neie Versuch',
'login_par_ici' => 'Dir sidd ugemeld... hei geet &euml;t weider...',
'login_pass2' => 'Passwuert:',
'login_preferez_refuser' => '<b>Wann dir keng Cookiee w&euml;llt</b>, hei ass eng aner (manner ges&euml;chert) Umeldungs-Method:',
'login_recharger' => 'd&euml;s S&auml;it nei lueden',
'login_rester_identifie' => 'E puer Deg ugemelt bleiwen',
'login_retour_public' => 'Zer&euml;ck op den &ouml;ffentl&euml;che Site',
'login_retour_site' => 'Zer&euml;ck op den &ouml;ffentl&euml;che Site',
'login_retoursitepublic' => 'zer&euml;ck&nbsp;op&nbsp;den&nbsp;&ouml;ffentl&euml;che&nbsp;Site',
'login_sans_cookiie' => 'Umeldung ouni Cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 's&euml;ch aschreiwen',
'login_test_navigateur' => 'Browser/Login-Test',
'login_verifiez_navigateur' => '(Kontroll&eacute;iert op &auml;re Browser d\'Passwuert n&euml;t gesp&auml;ichert huet...)',

// M
'masquer_colonne' => 'D&euml;s Kolonn verstoppen',
'masquer_trad' => 'Iwersetzungen verstoppen',
'module_fichiers_langues' => 'Sprooche-Fichier\'en',

// N
'navigateur_pas_redirige' => 'Wann &auml;re Browser n&euml;t weider geleed g&euml;tt, da klickt hei.',
'numero' => 'Nummer',

// O
'occurence' => 'K&euml;nnt fir',
'onglet_affacer_base' => 'Datebank l&auml;schen',
'onglet_auteur' => 'Den Auteur',
'onglet_contenu_site' => 'Inhalt vum Site',
'onglet_evolution_visite_mod' => '&Eacute;volutioun',
'onglet_fonctions_avances' => 'Fortgeschratten Fonktiounen',
'onglet_informations_personnelles' => 'Pers&eacute;inlech Informatiounen',
'onglet_interactivite' => 'Interaktivit&eacute;it',
'onglet_messagerie' => 'Messagerie',
'onglet_messages_internes' => 'Intern Messagen',
'onglet_messages_publics' => '&Ouml;ffentl&euml;ch Messagen',
'onglet_messages_vide' => 'Messagen ouni Text',
'onglet_origine_visites' => 'Origine vun de Visiten',
'onglet_repartition_debut' => 'z&euml;nter Ufank',
'onglet_repartition_lang' => 'Verdeelung no Sprooch',
'onglet_repartition_rubrique' => 'Verdeelung no Rubrik',
'onglet_save_restaur_base' => 'Datebank sp&auml;icheren/restaur&eacute;ieren',
'onglet_vider_cache' => 'Cache l&auml;schen',
'ortho_trop_de_fautes2' => 'Verbessert d&eacute;i einfachst Fehler a prob&eacute;iert nach eng K&eacute;ier.',

// P
'pass_choix_pass' => 'Wielt &auml;rt neit Passwuert:',
'pass_erreur' => 'Fehler',
'pass_erreur_acces_refuse' => '<b>Fehler:</b> dir hutt keen Zougang m&eacute;i zu d&euml;sem Site.',
'pass_erreur_code_inconnu' => '<b>Fehler:</b> d&euml;se Code entspr&euml;cht kengem Visiteur deen Zougang zu d&euml;sem Site huet.',
'pass_erreur_non_enregistre' => '<b>Fehler:</b> den Email <tt>@email_oubli@</tt> ass n&euml;t op d&euml;sem Site ugemelt.',
'pass_erreur_non_valide' => '<b>Fehler:</b> den Email <tt>@email_oubli@</tt> ass falsch!',
'pass_erreur_probleme_technique' => '<b>Fehler:</b> de Message kann duerch techn&euml;sch Problemer n&euml;t gesch&eacute;ckt ginn.',
'pass_espace_prive_bla' => 'De privaten Deel ass fir Visiteuren no enger Umeldung op. Wann dir ugemeld sidd k&euml;nnt der d\'Artikelen an der Aarbecht kucken, Artikelen propos&eacute;ieren an un de Forum\'en deelhuelen.',
'pass_forum_bla' => 'Dir hutt prob&eacute;iert un engem Forum deelzehuelen den fir d&eacute;i ugemelten Visiteuren reserv&eacute;iert ass.',
'pass_indiquez_cidessous' => 'Gitt hei den Email un &euml;nner dem der Iech ugemelt hutt. Dir kritt dann e Message mat den Instruktiounen fir &auml;ren Zougang er&euml;m ze kr&eacute;ien.',
'pass_mail_passcookie' => '(d&euml;st ass en automat&euml;schen Message)
Fir &auml;ren Zougang zum Site
@nom_site_spip@ (@adresse_site@)
er&euml;m ze kr&eacute;ien, gidd op d&euml;s Adress:

@sendcookie@

Dir k&euml;nnt do e neit Passwuert agin an Iech um Site umelden.

',
'pass_mot_oublie' => 'Passwuert vergiess',
'pass_nouveau_enregistre' => '&Auml;rt neit Passwuert ass gesp&auml;ichert.',
'pass_nouveau_pass' => 'Neit Passwuert',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Vergiessen vum Passwuert',
'pass_quitter_fenetre' => 'D&euml;s F&euml;nster zoumaachen',
'pass_rappel_login' => 'Rappel: &auml;r Identifikatioun (Login) ass "@login@".',
'pass_recevoir_mail' => 'Dir kritt e Message mat Instruktiounen fir den Zougang zum Site er&euml;m ze kr&eacute;ien.',
'pass_retour_public' => 'Zer&euml;ck op den &ouml;ffentl&euml;chen Site',
'pass_rien_a_faire_ici' => 'Hei g&euml;t &euml;t n&auml;ischt ze dinn.',
'pass_vousinscrire' => 'Iech op d&euml;sem Site aschreiwen',
'precedent' => 'Zer&euml;ck',
'previsualisation' => 'Pr&eacute;visualisatioun',
'previsualiser' => 'Pr&eacute;visualis&eacute;ieren',

// R
'retour' => 'Zer&euml;ck',

// S
'spip_conforme_dtd' => 'SPIP h&euml;lt d&euml;st Dokument als konform zu s&euml;ngem DOCTYPE un:',
'squelette' => 'Skelett',
'squelette_inclus_ligne' => 'Skelett abegraff, Zeil',
'squelette_ligne' => 'Skelett, Zeil',
'stats_visites_et_popularite' => '@visites@ Visiten; Popularit&eacute;it: @popularite@',
'suivant' => 'Weider',

// T
'taille_ko' => '@taille@&nbsp;kB',
'taille_mo' => '@taille@&nbsp;MB',
'taille_octets' => '@taille@&nbsp;Byte',
'texte_actualite_site_1' => 'Wann dir mam Interface familiaris&eacute;iert sidd, da k&euml;nnt der klicken op "',
'texte_actualite_site_2' => 'kompletten Interface',
'texte_actualite_site_3' => '" fir m&eacute;i M&eacute;iglechkeeten ze weisen.',
'texte_creation_automatique_vignette' => 'Automatesch Vignetten maachen ass op d&euml;sem Site ageschalt. Wann dir mat engem Formulaire Biller am Format @gd_formats@ eroplued, da kr&eacute;ien se eng Vignette vun enger maximaler Gr&eacute;isst vun @taille_preview@&nbsp;Pixel.',
'texte_documents_associes' => 'D&euml;s Dokumenter sinn un den Artikel gebonnen, awer n&euml;t direkt agef&uuml;gt. Je no Design vum Site ginn se als verlinkten Dokumenter gewisen.',
'texte_erreur_mise_niveau_base' => 'Datebank-Fehler beim Update.
D\'Bild <b>@fichier@</b> ass n&euml;t duerchgaang (Artikel @id_article@).
Not&eacute;iert d&euml;s Referenz, prob&eacute;iert nach eng K&eacute;ier, a kontroll&eacute;iert op d\'Biller an den Artikelen gewisen ginn.',
'texte_erreur_visiteur' => 'Dir hutt prob&eacute;iert mat engem n&euml;t erlaabten Login an de privaten Deel ze go&euml;n.',
'texte_inc_auth_1' => 'Dir sidd identifi&eacute;iert mam Login <b>@auth_login@</b>, mais d&euml;se Login g&euml;t &euml;t n&euml;t oder net m&eacute;i an der Datebank.
Prob&eacute;iert ',
'texte_inc_auth_2' => 'Iech unzemelden',
'texte_inc_auth_3' => ', eventuell nodeem der &auml;re Browser nei gestart hutt.',
'texte_inc_config' => 'D\'&Auml;nnerungen op d&euml;se S&auml;iten beaflossen de Fonktionnement vun &auml;rem Site ganz staark. Maacht n&auml;ischt ier d&euml;r de SPIP-System richteg kennt.<br /><br /><b>Generell ass ungeroden, d&euml;s S&auml;iten dem Webmaster vun &auml;rem Site ze iwwerloossen.</b>',
'texte_inc_meta_1' => 'De System huet e Fehler fonnt beim Schreiwen vum Fichier <code>@fichier@</code>. Als Administrateur vum Site,',
'texte_inc_meta_2' => 'kontroll&eacute;iert d\'Schreiw-Rechter',
'texte_inc_meta_3' => 'am Dossier <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'an der Aarbecht',
'texte_statut_poubelle' => 'an der Drecksk&euml;scht',
'texte_statut_propose_evaluation' => 'propos&eacute;iert',
'texte_statut_publie' => 'publiz&eacute;iert',
'texte_statut_refuse' => 'refus&eacute;iert',
'titre_ajouter_mot_cle' => 'SCHL&Euml;SSELWUERT DERB&Auml;I SETZEN:',
'titre_breve_proposee' => 'Propos&eacute;iert Kuerzmeldung',
'titre_breve_publiee' => 'Publiz&eacute;iert Kuerzmeldung',
'titre_breve_refusee' => 'Refus&eacute;iert Kuerzmeldung',
'titre_cadre_raccourcis' => 'OFKIIRZUNG:',
'titre_changer_couleur_interface' => 'Faarw vum Interface &auml;nneren',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Dir k&euml;nnt d&euml;sen Artikel administr&eacute;ieren',
'titre_image_administrateur' => 'Administrateur',
'titre_image_aide' => 'H&euml;llef fir d&euml;st Element',
'titre_image_auteur_supprime' => 'Gel&auml;schten Auteur',
'titre_image_redacteur' => 'Redakter ouni Zougang',
'titre_image_redacteur_02' => 'Redakter',
'titre_image_visiteur' => 'Visiteur',
'titre_joindre_document' => 'DOKUMENT DERB&Auml;I SETZEN',
'titre_liens_entrants' => 'Linken d&eacute;i eran komm sinn',
'titre_mots_cles' => 'SCHL&Euml;SSEL-WIERDER',
'titre_probleme_technique' => 'Opgepasst: e Problem (mam SQL-Server) verh&euml;nnert den Zougang op d&euml;sen Deel vum Site. Merci fir &auml;r Gedold.',
'titre_publier_document' => 'DOKUMENT AN D&Euml;SER RUBRIK PUBLIZ&Eacute;IEREN',
'titre_signatures_attente' => '&Euml;nnerschr&euml;ften d&eacute;i op Validatioun waarden',
'titre_signatures_confirmees' => 'Confirm&eacute;iert &Euml;nnerschr&euml;ften',
'titre_statistiques' => 'Statistik vum Site',
'titre_titre_document' => 'Titel vum Dokument:',
'todo' => 'k&euml;nnt nach',
'trad_reference' => '(Referenz-Artikel)',

// Z
'zbug_balise_b_aval' => ': B-Tag dr&euml;nner',
'zbug_balise_inexistante' => 'Feeler @from@: den Tag #@balise@ g&euml;tt et net', # MODIF
'zbug_balise_sans_argument' => 'Argument feelt am Tag @balise@',
'zbug_boucle' => '-eidel-',
'zbug_boucle_recursive_undef' => 'Rekursiv Boucle n&euml;t defin&eacute;iert', # MODIF
'zbug_calcul' => 'Berechnung',
'zbug_champ_hors_boucle' => 'Feld @champ@ ausserhalb vun der Boucle',
'zbug_champ_hors_motif' => 'Feld @champ@ ausserhalb vun enger Boucle mam Motiv @motif@', # MODIF
'zbug_code' => '-Code-',
'zbug_critere_inconnu' => 'Onbekannten Crit&egrave;re @critere@', # MODIF
'zbug_distant_interdit' => 'extern verbueden', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'Duebel Valeuren an enger Tabell ouni atomaren primairen Schl&euml;ssel', # MODIF
'zbug_doublon_table_sans_index' => 'Verduebelung an enger Tabell ouni Index', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: duebel Definitioun', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: Schluss-Tag fehlt', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Falsch Syntax vun der Schleef', # MODIF
'zbug_erreur_compilation' => 'Kompilatiouns-Fehler',
'zbug_erreur_execution_page' => 'Fehler beim Berechnen vun der S&auml;it', # MODIF
'zbug_erreur_filtre' => 'Fehler: Filter <b>"@filtre@"</b> n&euml;t defin&eacute;iert', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} ass just fir d\'Bouclen (FORUMS) oder (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Fehler am Skelett',
'zbug_hors_compilation' => 'Ausserhalb vun der Compilatioun',
'zbug_info_erreur_squelette' => 'Fehler um Site',
'zbug_inversion_ordre_inexistant' => 'Inversioun vun enger Uerdnung d&eacute;i &euml;t n&euml;t g&euml;tt', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION ouni {pagination}-Crit&egrave;re oder an &euml;nger rekursiver Schl&auml;if gebraucht', # MODIF
'zbug_parametres_inclus_incorrects' => 'Falsch Parameteren fir d\'Inclusioun', # MODIF
'zbug_profile' => 'Rechenz&auml;it: @time@',
'zbug_resultat' => '-eidel-',
'zbug_serveur_indefini' => 'SQL-Server n&euml;t defin&eacute;iert', # MODIF
'zbug_statistiques' => 'Statistik vun den SQL-Query\'en, klass&eacute;iert no der L&auml;ngt',
'zbug_table_inconnue' => 'Onbekannten SQL-Tabell "@table@"',
'zxml_connus_attributs' => 'Bekannten Attributer',
'zxml_de' => 'vun',
'zxml_inconnu_attribut' => 'Onbekanntent Attribut',
'zxml_inconnu_balise' => 'Onbekannten Tag',
'zxml_inconnu_entite' => 'Onbekannten Entit&eacute;it',
'zxml_inconnu_id' => 'Onbekannten ID',
'zxml_mais_de' => 'mais vun',
'zxml_non_conforme' => 'ass n&euml;t konform zum Motiv',
'zxml_non_fils' => 'ass kee Kand vun',
'zxml_nonvide_balise' => 'Tag n&euml;t eidel',
'zxml_obligatoire_attribut' => 'Obligator&euml;scht Attribut, fehlt awer an',
'zxml_succession_fils_incorrecte' => 'Reihenfolge vun de Kanner n&euml;t richteg',
'zxml_survoler' => 'driwer fl&eacute;ien fir d&eacute;i Richteg ze gesinn',
'zxml_valeur_attribut' => 'Valeur vum Attribut',
'zxml_vide_balise' => 'Eidelen Tag',
'zxml_vu' => 'virdru gesinn'
);

?>
